@@ -39,7 +39,7 @@ class AnityaProcessor(BaseProcessor):
         try:
             email = msg['msg']['message']['agent']
         except KeyError:
-            return msg['username']
+            return msg.get('username', 'anitya')
         else:
             if email.endswith('@fedoraproject.org'):
                 return email.split('@fedoraproject.org')[0]
@@ -91,7 +91,8 @@ class AnityaProcessor(BaseProcessor):
         elif 'project.add.tried' in msg['topic']:
             project = msg['msg']['project']['name']
             tmpl = self._('{user} tried to add the project '
-                          '"{project}" to anitya')
+                          '"{project}" to anitya '
+                          '(but it already exists there)')
             return tmpl.format(user=user, project=project)
         elif 'project.add' in msg['topic']:
             project = msg['msg']['project']['name']
@@ -131,6 +132,12 @@ class AnityaProcessor(BaseProcessor):
                     'A new version of "{project}" has been detected:  '
                     '"{new}" in advance of "{old}"')
             return tmpl.format(project=project, new=new, old=old)
+        elif 'project.version.remove' in msg['topic']:
+            project = msg['msg']['project']['name']
+            version = msg['msg']['message']['version']
+            tmpl = self._(
+                '{user} deleted the version {version} of "{project}"')
+            return tmpl.format(user=user, project=project, version=version)
         else:
             pass
 
@@ -167,6 +174,8 @@ class AnityaProcessor(BaseProcessor):
                 'distros/%s' % distro,
                 'projects/%s' % msg['msg']['project']['name'],
             ])
+        elif 'project.version.remove' in msg['topic']:
+            return set(['projects/%s' % msg['msg']['project']['name']])
         elif 'project.remove' in msg['topic']:
             return set(['projects/%s' % msg['msg']['project']['name']])
         elif 'project.map.remove' in msg['topic']:
